import { Component } from 'vue';
import { ComponentOptionsMixin } from 'vue';
import { ComponentProvideOptions } from 'vue';
import { CSSProperties } from 'vue';
import { DefineComponent } from 'vue';
import { ExtractPropTypes } from 'vue';
import { InjectionKey } from 'vue';
import { PropType } from 'vue';
import { PublicProps } from 'vue';
import { Ref } from 'vue';
import { RendererElement } from 'vue';
import { RendererNode } from 'vue';
import { VNode } from 'vue';
import { VNodeProps } from 'vue';

export declare type ComponentType = Component | DefineComponent;

export declare interface Field {
    name: string;
    props: Props;
    slots?: Recordable<() => void>;
    on?: Recordable<string | ((event: any, $inject: InjectionType, ref: Ref<any>, field: Field) => void) | undefined>;
}

export declare type Hook = (field: Field, inject?: InjectionType) => void;

export declare type InjectionType = {
    readonly?: boolean;
    rootRef?: Ref<any>;
    hook?: Hook;
    [key: string]: any;
};

export declare interface Options {
    type: 'string' | 'boolean' | 'number';
    value: any;
    label: string;
    disabled?: boolean;
    children?: Options[];
}

export declare interface Props extends VNodeProps {
    style?: CSSProperties;
    class?: string[];
    options?: Options[];
    [key: string]: any;
}

export declare type Recordable<T = any> = Record<string, T>;

declare const Render: DefineComponent<ExtractPropTypes<    {
field: {
type: PropType<Field>;
required: true;
};
modelValue: {
type: PropType<any>;
required: false;
};
hook: {
type: PropType<Hook>;
required: false;
};
is: {
type: PropType<string | ComponentType>;
required: false;
};
readonly: {
type: PropType<boolean>;
required: false;
default: boolean;
};
}>, () => VNode<RendererNode, RendererElement, {
[key: string]: any;
}>, {}, {}, {}, ComponentOptionsMixin, ComponentOptionsMixin, {
'update:modelValue': (value: any) => true;
input: (value: any) => true;
}, string, PublicProps, Readonly<ExtractPropTypes<    {
field: {
type: PropType<Field>;
required: true;
};
modelValue: {
type: PropType<any>;
required: false;
};
hook: {
type: PropType<Hook>;
required: false;
};
is: {
type: PropType<string | ComponentType>;
required: false;
};
readonly: {
type: PropType<boolean>;
required: false;
default: boolean;
};
}>> & Readonly<{
"onUpdate:modelValue"?: ((value: any) => any) | undefined;
onInput?: ((value: any) => any) | undefined;
}>, {
readonly: boolean;
}, {}, {}, {}, string, ComponentProvideOptions, true, {}, any>;
export default Render;

export declare const RENDER_INJECTION_KEY: InjectionKey<string>;

export { }
